from setuptools import setup

setup(name='downloadpdf',
      version='1.0.1',
      description='Downloads PDFs from URL',
      url='https://codeanit.com/',
      author='Anit Shrestha Manandhar',
      author_email='codeanit@gmail.com',
      license='MIT',
      packages=['downloadpdf'],
      zip_safe=False,
      python_requires='>=3.6',
      install_requires=['beautifulsoup4==4.10.0'])
